@@ -1,6 +1,7 @@
-#  Copyright (c) 1997-2018
-#  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-#  http://www.polymake.org
+#  Copyright (c) 1997-2024
+#  Ewgenij Gawrilow, Michael Joswig, and the polymake team
+#  Technische Universität Berlin, Germany
+#  https://polymake.org
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -24,6 +25,27 @@ if you already have an up-to-date perl interpreter somewhere else,
 you can specify its location on the command line:
 
 ./configure PERL=/path/to/my/new/perl [other options ...]
+.
+      exit(1);
+   } elsif ($] >= 5.042) {
+      print STDERR <<".";
+*************
+*** ERROR ***
+*************
+
+polymake has not been checked for compatibility with perl 5.42 or newer;
+your perl interpreter says it is $].
+
+If you already have another (older) perl interpreter somewhere else, you can
+specify its location on the command line:
+
+./configure PERL=/path/to/my/new/perl [other options ...]
+
+You can install a custom perl version in your home directory using perlbrew
+(https://perlbrew.pl). Make sure to append '-Duseshrplib' to the install
+command if you want to use libpolymake (e.g. for the jupyter interface) and to
+install all required perl modules which are listed after running configure
+again with the new perl.
 .
       exit(1);
    }
@@ -36,7 +58,6 @@ use File::Path;
 use strict 'vars', 'subs';
 use lib "perllib";
 
-my $root=Cwd::getcwd;
 my ($NeedsArchFlag);
 
 my $Wiki="http://www.polymake.org/doku.php";
@@ -54,8 +75,6 @@ $| = 1;
 package Polymake;
 use vars qw( $DeveloperMode $Shell $filename_re $directory_of_cmd_re );
 
-$DeveloperMode=-d "$root/testscenarios";
-
 use Polymake::ConfigureStandalone;
 
 $Shell=new FakeNoShell;
@@ -71,7 +90,7 @@ my (%options, %vars, %allowed_options, %allowed_with, %allowed_flags, %allowed_v
 
 # expected options for the core script
 @allowed_options{ qw( prefix exec-prefix bindir includedir libdir libexecdir datadir docdir build build-modes ) }=();
-@allowed_with{ qw( gmp mpfr libxml2 boost permlib toolchain ccache ccwrapper) }=();
+@allowed_with{ qw( gmp mpfr boost permlib toolchain ccache ccwrapper ) }=();
 @allowed_flags{ qw( prereq callable native openmp libcxx ) }=();
 @allowed_vars{ qw( CC CFLAGS CXX CXXFLAGS CXXOPT CXXDEBUG LDFLAGS LIBS Arch DESTDIR ) }=();
 
@@ -82,9 +101,14 @@ if ($^O eq "darwin") {
 my (@ext, @ext_disabled, %ext_with_config, %ext_requires, %ext_requires_opt, %ext_conflicts, %ext_failed, %ext_bad,
     @ext_ordered, %ext_survived);
 
-my $repeating_config=early_parse_command_line();
-my $BuildDir= $options{build} ? "build.$options{build}" : "build";
-my $perlxpath="perlx/$Config::Config{version}/$Config::Config{archname}";
+my $repeating_config = early_parse_command_line();
+my $root = Cwd::getcwd;
+$Polymake::DeveloperMode = -d "$root/testscenarios";
+
+my $BuildDir = $options{build} ? "build.$options{build}" : "build";
+my $perlxpath = "perlx/$Config::Config{version}/$Config::Config{archname}";
+my $perlextraflags = "";
+my $autogold = 0;
 
 load_enabled_bundled_extensions();
 parse_command_line(\@ARGV, $repeating_config);
@@ -105,11 +129,11 @@ if ($options{'alt-perl'}) {
 my %store_versions;
 locate_gmp_and_mpfr_libraries();
 locate_boost_headers();
-locate_libxml2();
 locate_permlib();
 
-# there is no independent package for TOSimplex, always pick the bundled headers
-$ExternalHeaders .= " TOSimplex";
+# there is no independent package for TOSimplex and Minimball, always pick the bundled headers
+$ExternalHeaders .= " TOSimplex Miniball";
+
 
 if ($options{prereq} ne ".none.") {
    check_prerequisite_perl_packages();
@@ -194,6 +218,8 @@ Allowed options (and their default values) are:
                               or for packagers.
                               By default, a single "build" directory is created.
 
+  --builddir PATH     An alternative way of specifying an existing build directory by its full path
+
  Installation directories:
 
   --prefix=PATH       ( /usr/local )                   root of the installation tree
@@ -216,13 +242,12 @@ Allowed options (and their default values) are:
    $^O eq "darwin" and
    print STDERR <<'---';
   --with-fink=PATH         fink installation directory. You can pass "default" as argument if fink is installed into its default location ( /sw )
-  --with-brew=PATH         homebrew installation directory. You can pass "default" as argument if brew is installed into its default location ( /usr/local )
+  --with-brew=PATH         homebrew installation directory. You can pass "default" as argument if brew is installed into its default location ( /usr/local for intel Macs or /opt/homebrew for silicon Macs)
 .
 ---
    print STDERR <<"---";
   --with-gmp=PATH     ( /usr ) GNU MultiPrecision library installation directory
   --with-mpfr=PATH    ( =gmp-path ) GNU Multiple Precision Floating-point Reliable library installation directory
-  --with-libxml2=PATH ( find via \$PATH ) GNU XML processing library
 
   --with-boost=PATH   installation path of boost library, if non-standard
 
@@ -323,24 +348,38 @@ For detailed installation instructions, please refer to the polymake Wiki site:
 
 ###################################################################################
 # * sieve out disabled extensions so that their configuration scripts are not loaded
-# * process --build, --build-modes, and --defaults
+# * process --build, --builddir, --build-modes, and --defaults
 # * restore options from previous runs if desired
 sub early_parse_command_line {
    my (@other_args, $enforce_defaults);
-   while (defined (my $arg=shift @ARGV)) {
+   while (defined(my $arg = shift @ARGV)) {
       if ($arg eq "--defaults") {
-         $enforce_defaults=1;
-      } elsif (my ($flag, $value)= $arg =~ /^--(build(?:-modes)?|alt-perl)(?:=(\S+))?$/) {
+         $enforce_defaults = 1;
+      } elsif (my ($flag, $value) = $arg =~ /^--(build(?:-modes|dir)?|alt-perl)(?:=(\S+))?$/) {
          $value //= @ARGV && $ARGV[0] =~ /^\w/ ? shift @ARGV : die "option --$flag requires a value\n";
-         $options{$flag}=$value;
+         $options{$flag} = $value;
       } elsif ($arg =~ /^--without-(\w+)$/  &&  -d "bundled/$1") {
          push @ext_disabled, $1;
-         $options{$1}=".none.";
+         $options{$1} = ".none.";
       } else {
          push @other_args, $arg;
       }
    }
 
+   if (my $builddir = delete $options{'builddir'}) {
+      if ($options{build}) {
+         die "--build and --builddir may not be specified together\n"
+      }
+      if (-f "$builddir/config.ninja" && $builddir =~ s{/build(?:\.([^/]+))?(?:/\w+)?$}{}) {
+         chdir $builddir or die "can't change into $builddir: $!\n";
+         if (defined($1)) {
+            $options{build} = $1;
+         }
+      } else {
+         die "$builddir does not look like a configured polymake build directory\n";
+      }
+   }
+
    if ($options{'alt-perl'}) {
       if ($enforce_defaults || @other_args || @ext_disabled) {
          die "option --alt-perl can't be combined with any other configuration option\n";
@@ -549,7 +588,6 @@ sub construct_paths {
    $InstallTop=$options{datadir} || "$prefix/share/polymake";
    $InstallArch=$options{libexecdir} || "$exec_prefix/lib/polymake";
    $InstallInc=$options{includedir} || "$prefix/include";
-   $InstallDoc=$options{docdir} || "$InstallTop/doc";
 }
 
 #####################################################
@@ -599,13 +637,14 @@ int main() {
    my $build_error;
 
    # try to use gold linker unless another linker has been prescribed by the user
-   unless ($^O eq "darwin" or "$CXXFLAGS $LDFLAGS" =~ /(?:^|\s)-fuse-ld[=\s]/) {
+   unless ($^O eq "darwin" or $Config::Config{archname} =~ /^mips/ or "$CXXFLAGS $LDFLAGS" =~ /(?:^|\s)-fuse-ld[=\s]/) {
       $build_error = build_test_program($cxx_tell_version, LDFLAGS => "-fuse-ld=gold");
       if ($?) {
          # did not work out, maybe gold is missing?
          undef $build_error;
       } else {
          $LDFLAGS .= " -fuse-ld=gold";
+         $autogold = 1;
       }
    }
    $build_error //= build_test_program($cxx_tell_version);
@@ -743,7 +782,7 @@ Please investigate and reconfigure.
            $cppver >= 201305 and
                defined($CLANGversion) and v_cmp($CLANGversion, "3.5") < 0
           ) {
-      # C++ standard older than C++14 wont work (C++1y from clang 3.4 is also ok)
+      # C++ standard older than C++14 won't work (C++1y from clang 3.4 is also ok)
       die "C++ standard version ($cppver) too old, C++14 or later is required. Please omit any '-std=' options.\n";
    }
 
@@ -831,11 +870,20 @@ If you have renamed the main fink program, please specify the top directory: --w
 #####################################################
 sub check_brew {
    $BrewBase=$options{brew};
-   if ( $BrewBase eq "default" ) {
-      $BrewBase = '/usr/local';
+   my $local_arch = `uname -m`;
+   chomp $local_arch;
+   if ( $BrewBase eq "default" || ( $local_arch == "x86_64" && $BrewBase eq "/usr/local" ) || ( $local_arch == "arm64" && $BrewBase eq '/opt/homebrew' ) ) {
+      $BrewBase = $Arch == "x86_64" ? '/usr/local' : '/opt/homebrew';
       unless (-f "$BrewBase/bin/brew") {
          die "brew installation corrupt: $BrewBase/bin/brew not found\n";
       }
+   } elsif( $BrewBase eq "bottle" ) {
+      $ADDITIONAL_PERL_INCLUDES = "";
+      my @perl_paths = split(/:/, "$ENV{PERL5LIB}");
+      foreach (@perl_paths) {
+         $ADDITIONAL_PERL_INCLUDES .= " -I$_";
+      }
+      $BrewBase = '#{HOMEBREW_PREFIX}';
    } else {
       if (-d $BrewBase) {
          unless (-f "$BrewBase/bin/brew") {
@@ -889,12 +937,10 @@ sub determine_architecture {
    print "determining architecture ... ";
    if ($^O eq "darwin") {
       if ( !defined($FinkBase) && !defined($BrewBase) ) {
-         if (defined $Arch) {
-            if ($Arch ne "i386" && $Arch ne "x86_64") {
-               die "Invalid architecture $Arch for Mac OS: allowed values are i386 and x86_64.\n";
-            }
-         } else {
-            $Arch = "x86_64";
+         $Arch //= `uname -m`;
+         chomp $Arch;
+         if ($Arch ne "arm64" && $Arch ne "i386" && $Arch ne "x86_64") {
+            die "Invalid architecture $Arch for Mac OS: allowed values are i386, x86_64 and arm64.\n";
          }
       }
       $ARCHFLAGS= $NeedsArchFlag ? "-arch $Arch" : "";
@@ -927,7 +973,7 @@ sub collect_compiler_specific_options {
       # avoid using temp files, they grow indeterminately during debug builds
       $CsharedFLAGS="-fPIC -pipe";
       # TODO: remove -fno-strict-aliasing when the core library is free from reintepret_casts
-      $CXXFLAGS .= " -ftemplate-depth-200 -fno-strict-aliasing -Wno-parentheses -Wshadow";
+      $CXXFLAGS .= " -ftemplate-depth-200 -fno-strict-aliasing";
       if ($options{openmp} ne ".none.") {
          $CXXFLAGS .= " -fopenmp";
          $LDFLAGS .= " -fopenmp";
@@ -935,12 +981,26 @@ sub collect_compiler_specific_options {
       $CXXCOV="--coverage -O1";
       $CXXSANITIZE="-fno-omit-frame-pointer -O1 " . ($CXXDEBUG =~ /(?:^|\s)-g0/ ? "-g1" : $CXXDEBUG);
       # external libraries might be somehow dirtier
-      $CflagsSuppressWarnings="";
+      $CflagsSuppressWarnings="-Wno-unused-result";
       # gcc-specific flags
-      $CXXFLAGS .= " -Wno-error=unused-function";
+      $CXXFLAGS .= " -Wshadow -Wlogical-op -Wconversion -Wzero-as-null-pointer-constant -Wno-parentheses -Wno-error=unused-function";
       if (v_cmp($GCCversion, "6.3.0") >= 0 && v_cmp($GCCversion, "7.0.0") < 0) {
          $CXXFLAGS .= " -Wno-maybe-uninitialized";
       }
+      if (v_cmp($GCCversion, "9.1.0") >= 0) {
+         $CXXFLAGS .= " -Wno-stringop-overflow";
+         $CflagsSuppressWarnings.=" -Wno-stringop-overflow";
+      }
+      if (v_cmp($GCCversion, "10.0.0") >= 0) {
+         $CXXFLAGS .= " -Wno-array-bounds";
+      }
+      if (v_cmp($GCCversion, "11.0.0") >= 0) {
+         $CXXFLAGS .= " -Wno-maybe-uninitialized -Wno-free-nonheap-object";
+      }
+      if (v_cmp($GCCversion, "14.0.0") >= 0) {
+         # due to false positives
+         $CXXFLAGS .= " -Wno-dangling-reference";
+      }
 
    } elsif (defined($ICCversion)) {
       $CsharedFLAGS="-fPIC";
@@ -956,11 +1016,13 @@ sub collect_compiler_specific_options {
       if (v_cmp($CLANGversion, "3.6") >= 0) {
          $CXXFLAGS .= " -Wno-unused-local-typedef -Wno-error=unneeded-internal-declaration";
       }
-      if (v_cmp($CLANGversion, "3.9") >= 0) {
-         # earlier versions produce bizarre false positives in nested classes methods
-         $CXXFLAGS .= " -Wshadow";
+      if (v_cmp($CLANGversion, "5") >= 0) {
+         $CXXFLAGS .= " -Wshadow -Wconversion -Wno-sign-conversion -Wzero-as-null-pointer-constant";
+      } elsif (v_cmp($CLANGversion, "4") >= 0) {
+         $CXXFLAGS .= " -Wno-unknown-pragmas -Wno-unknown-warning-option";
+      } else {
+         $CXXFLAGS .= " -Wno-unknown-pragmas";
       }
-
       # verify openmp support which is available starting with 3.7 but depends on the installation,
       # but 3.7 seems to crash when compiling libnormaliz so we skip that version
       # version 3.8 is tested to work with openmp
@@ -1189,6 +1251,65 @@ The complete error log follows:
    }
 }
 
+sub check_gmpxx {
+   # check GMP C++ bindings
+   my $build_error=build_test_program(<<'---', LIBS => "-lgmpxx -lgmp");
+#include <cstddef>
+#include <gmpxx.h>
+int main() {
+   mpz_class z(7);
+   mpz_class y(z-z);
+   return y.get_si();
+}
+---
+   if ($?==0) {
+      my $run_error = run_test_program();
+      if ($?) {
+         die "Could not run a test program linked to the C++ version of the GNU Multiprecision Library (GMP).\n",
+             "Probably the shared library libgmpxx.$Config::Config{dlext} is missing or of an incompatible machine type:\n$run_error\n";
+      }
+   } else {
+      die "Could not compile a test program checking for C++ bindings of the GNU Multiprecision Library (GMP).\n",
+          "The most probable reasons are that a gmpxx package is missing, lacking the developer's subpackage \n",
+          "or GMP was configured without C++ support (--enable-cxx).\n",
+          "Please refer to the installation instructions at $Wiki/howto/install.\n",
+          "The complete error log follows:\n", $build_error;
+   }
+}
+
+sub check_gmpxx_ostream {
+   my $extraflags = "";
+   # check GMP C++ library
+OSTREAM_CHECK:
+   my $build_error=build_test_program(<<'---', CXXFLAGS => "$extraflags", LIBS => "$ARCHFLAGS -lgmpxx -lgmp");
+#include <cstddef>
+#include <gmpxx.h>
+#include <iostream>
+
+#ifdef PM_MIXED_OSTREAM
+std::ostream& operator<< (std::ostream &s, mpq_srcptr r) {
+   return s << 1;
+}
+#endif
+int main() {
+   mpq_class x(7,3);
+   std::cout << x << std::endl;
+   return 0;
+}
+---
+      my $run_error = run_test_program() if $? == 0;
+      if ($?!=0) {
+         if ($extraflags) {
+            die "Could not build and run a test program checking the C++ library used by the GNU Multiprecision Library (GMP):\nbuild: $build_error\nrun:$run_error\n";
+         } else {
+            $extraflags = " -DPM_MIXED_OSTREAM";
+            goto OSTREAM_CHECK;
+         }
+      } elsif ($extraflags) {
+         $CXXFLAGS .= $extraflags;
+      }
+}
+
 ##########################################################
 sub locate_boost_headers {
    my $boost_path=$options{boost};
@@ -1234,7 +1355,9 @@ Please install the library and specify its location using --with-boost option, i
    }
 }
 
+
 ###############################################################
+
 sub locate_permlib {
    my $permlib_path = $options{permlib};
    if (defined($permlib_path) and $permlib_path ne "bundled") {
@@ -1323,23 +1446,22 @@ Otherwise, reconfigure and reinstall your perl.
          $_ =~ s/(?:^|\s+)-arch\s+\w+//g for $perlcflags, $perlldflags; 
       }
    }
-   my $build_error=build_test_program(<<'---', CXXFLAGS => (defined($CLANGversion) && "-Wno-reserved-user-defined-literal ").$perlcflags, LDFLAGS => "$ARCHFLAGS $perlldflags" );
+RETRYLIBPERL:
+   my $build_error=build_test_program(<<'---', CXXFLAGS => (defined($CLANGversion) && "-Wno-reserved-user-defined-literal ")."$perlcflags $perlextraflags", LDFLAGS => "$ARCHFLAGS $perlldflags" );
 #include <EXTERN.h>
 #include <perl.h>
 
-static PerlInterpreter *my_perl;
-
 int main(int argc, char **argv, char **env)
 {
    const char* embedding[] = { "", "-e", "print $];", 0 };
    PERL_SYS_INIT3(&argc, &argv, &env);
-   my_perl = perl_alloc();
-   perl_construct(my_perl);
+   pTHXx = perl_alloc();
+   perl_construct(aTHXx);
    PL_exit_flags |= PERL_EXIT_DESTRUCT_END;
-   perl_parse(my_perl, NULL, 3, (char**)embedding, (char **)NULL);
-   perl_run(my_perl);
-   perl_destruct(my_perl);
-   perl_free(my_perl);
+   perl_parse(aTHXx_ nullptr, 3, (char**)embedding, nullptr);
+   perl_run(aTHXx);
+   perl_destruct(aTHXx);
+   perl_free(aTHXx);
    PERL_SYS_TERM();
 }
 ---
@@ -1364,6 +1486,20 @@ perl-devel or libperl-dev.  Please look for such a package and install it.
 ---
       }
    } else {
+      if (defined($GCCversion) && $perlextraflags !~ /-D_Thread_local/ && $build_error =~ /error:.+_Thread_local.+does not name a type/s) {
+         # The PERL_THREAD_LOCAL macro might be set to _Thread_local (since perl 5.35.5).
+         # This is defined in the C11 standard and supported by all relevant gcc versions.
+         # But g++ (gcc in C++ mode) does not accept _Thread_local so we define that to thread_local instead.
+         # clang and clang++ both accept _Thread_local.
+         $perlextraflags .= " -D_Thread_local=thread_local";
+         goto RETRYLIBPERL;
+      }
+      if ($autogold && $LDFLAGS =~ /-fuse-ld=gold/ && $build_error =~ /ld\.gold.*unknown -z option/s) {
+         # some distributions have extra flags in the perl settings that the gold linker
+         # doesn't understand, so switch back to the default linker in that case
+         $LDFLAGS =~ s/-fuse-ld=gold//g;
+         goto RETRYLIBPERL;
+      }
       $error = <<"---";
 Could not compile a test program for the libperl.$Config::Config{so} shared library.
 The build error is as follows:
@@ -1393,7 +1529,7 @@ sub check_prerequisite_perl_packages {
       lib->import("$FinkBase/lib/perl5");
    }
    my @warned;
-   foreach (qw(XML::Writer XML::LibXML XML::LibXSLT Term::ReadKey Term::ReadLine JSON)) {
+   foreach (qw(XML::SAX Term::ReadKey Term::ReadLine JSON)) {
       my $pkg=$_;
       print "checking perl module $pkg ... ";
       my $warn;
@@ -1446,38 +1582,6 @@ WARNING: Please install/check the following perl modules prior to starting polym
    }
 }
 
-#######################################################################
-sub locate_libxml2 {
-   print "checking libxml2 installation ... ";
-   # gather build options for libxml2
-   my $xml2=$options{libxml2};
-   if (defined($xml2)) {
-      if (-x "$xml2/bin/xml2-config") {
-         $xml2="$xml2/bin/xml2-config";
-      } elsif (-x "$xml2/xml2-config") {
-         $xml2="$xml2/xml2-config";
-      } elsif ($xml2 !~ /-config$/ || !-x $xml2) {
-         die "Could not derive the location of the configuration program xml2-config from the option --with-libxml2\n";
-      }
-   } else {
-      $xml2="xml2-config";
-   }
-   $LIBXML2_CFLAGS=`xml2-config --cflags`;
-   if ($?) {
-      die <<"---";
-Could not find configuration program xml2-config for library libxml2.
-Probably you need to install development package for it;
-usually it is called libxml2-devel or similarly.
-If the library is installed at a non-standard location,
-please specify it in option --with-libxml2
----
-   }
-   chomp $LIBXML2_CFLAGS;
-   $LIBXML2_LIBS=`xml2-config --libs`;
-   chomp $LIBXML2_LIBS;
-   print "ok", defined($options{libxml2}) && " ($options{libxml2})", "\n";
-}
-
 #########################################################################
 sub bundled_ext_error_msg {
    my ($ext, $msg)=@_;
@@ -1555,6 +1659,9 @@ sub configure_enabled_bundled_extensions {
                print "failed";
                bundled_ext_error_msg($ext, $@);
                $enable=0;
+            } elsif ($result =~ /^disabled/) {
+               $enable=0;
+               print $result;
             } else {
                print "ok", $result ? " ($result)":"";
             }
@@ -1587,19 +1694,50 @@ You can also disable it by specifying --without-$ext instead.
    $BundledExts = join(" ", grep { $ext_survived{$_} } @ext_ordered);
 
    if ($options{prereq} ne ".none.") {
-      $warning .= <<"---" unless exists $ext_survived{"cdd"};
+      my $ext_warning;
+
+      $ext_warning .= <<"---" unless exists $ext_survived{"cdd"};
 
 WARNING: The bundled extension for cdd was either disabled or failed to configure.
          Running polymake without cdd is deprecated and not supported!
          Please recheck your configuration and $BundledLOGfile.
 ---
 
-      $warning .= <<"---" unless (exists $ext_survived{"nauty"} or exists $ext_survived{"bliss"});
+      $ext_warning .= <<"---" unless (exists $ext_survived{"nauty"} or exists $ext_survived{"bliss"});
 
 WARNING: The bundled extensions for bliss and nauty were both either disabled or failed to configure.
          Running polymake without a tool for graph-isomorphism tests is not supported!
          Please recheck your configuration and $BundledLOGfile.
 ---
+
+      $ext_warning .= <<"---" unless exists $ext_survived{"flint"};
+
+WARNING: The bundled extension for flint was either disabled or failed to configure.
+         Running polymake without flint is not supported!
+         QuadraticExtension types cannot be normalized in this configuration.
+         Please recheck your configuration and $BundledLOGfile.
+---
+
+      # check for non-supported configuration:
+      # failed required extensions but not disabled explicitly
+      if ($ext_failed{cdd} || $ext_failed{flint} ||
+          $ext_failed{bliss} && $ext_failed{nauty}) {
+
+         print $ext_warning;
+         die(<<"---");
+
+ERROR: Configuration failed:
+       At least one required bundled extension failed to configure.
+       This error can be suppressed by disabling them explicitly via '--without-<ext>'.
+---
+      } elsif ($ext_warning) {
+         $warning .= <<"---";
+$ext_warning
+* WARNING: Unsupported configuration:
+* Some required bundled extensions were disabled explicitly.
+* polymake will work but with reduced functionality.
+---
+      }
    }
 
    print "* If you want to change the configuration of bundled extensions please ",
@@ -1624,7 +1762,7 @@ sub finalize_compiler_flags {
       $LIBS .= " -ldl";
    }
 
-   $LIBS="-lmpfr -lgmp -lpthread $LIBS";
+   $LIBS="$LIBS -lmpfr -lgmp -lpthread";
 
    # be rigorous about own code
    if ($Polymake::DeveloperMode) {
@@ -1650,7 +1788,7 @@ It can usually be installed as a ready-to-use package, e.g.
 on Ubuntu:
    apt-get install ninja-build
 on MacOS with Homebrew:
-   brew install ninja-build
+   brew install ninja
 
 As a fallback, you can obtain its source code from GitHub, build it yourself,
 and install at a location of your choice:
@@ -1667,7 +1805,7 @@ sudo install -s -m 555 ninja $INSTALL_DIR
 
 ##############################################################################
 sub write_configuration_file {
-   my ($filename)=@_;
+   my ($filename) = @_;
    open my $conf, ">", $filename
      or die "can't create $filename: $!\n";
 
@@ -1718,15 +1856,23 @@ sub write_perl_specific_configuration_file {
    if ($] < 5.020 && defined($GCCversion)) {
       $no_warn .= " -Wno-literal-suffix";
    }
+   if (defined($CLANGversion) && v_cmp($CLANGversion, "10") >= 0) {
+      $no_warn .= " -Wno-xor-used-as-pow";
+   }
 
    # Xcode 10 deeply hides perl headers at unpredictable locations, it requires a special clang option to find them
    my $includePerlCore = defined($XcodeVersion) && v_cmp($XcodeVersion, "10.0") >= 0 && $Config::Config{perlpath} eq "/usr/bin/perl" ? "-iwithsysroot " : "-I";
 
+   # fedora has ExtUtils::ParseXS in vendorlib
+   my ($xsubpp) = grep { -e $_ } map { "$Config::Config{$_}/ExtUtils/xsubpp" } qw(privlib vendorlib);
+   my ($typemap) = grep { -e $_ } map { "$Config::Config{$_}/ExtUtils/typemap" } qw(privlib vendorlib);
+
    print $conf <<"---";
 PERL=$Config::Config{perlpath}
-CXXglueFLAGS=$includePerlCore$Config::Config{archlibexp}/CORE $Config::Config{ccflags} -DPerlVersion=$PerlVersion $no_warn
+CXXglueFLAGS=$includePerlCore$Config::Config{archlibexp}/CORE $Config::Config{ccflags} $perlextraflags -DPerlVersion=$PerlVersion $no_warn
 LIBperlFLAGS=-L$Config::Config{archlib}/CORE -lperl $Config::Config{ccdlflags}
-ExtUtils=$Config::Config{privlib}/ExtUtils
+ExtUtils_xsubpp=$xsubpp
+ExtUtils_typemap=$typemap
 ---
 
    close $conf;
@@ -1754,10 +1900,10 @@ sub create_alt_perl_configuration {
 
    File::Path::make_path("$BuildDir/$perlxpath");
    write_perl_specific_configuration_file("$BuildDir/$perlxpath/config.ninja");
-   my $buildroot="$root/$BuildDir";
+   my $builddir = "$root/$BuildDir";
    foreach my $mode ($BuildModes =~ /(\S+)/g) {
-      create_build_mode_subtree($buildroot, $mode);
-      write_build_ninja_file($buildroot, $mode, "build.$options{'alt-perl'}.ninja", perlxpath => $perlxpath);
+      create_build_mode_subtree($builddir, $mode);
+      write_build_ninja_file($builddir, $mode, "build.$options{'alt-perl'}.ninja", perlxpath => $perlxpath);
    }
 }
 
